@@ -1,8 +1,24 @@
 from office365.runtime.client_object import ClientObject
+from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
+from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 from office365.runtime.resource_path import ResourcePath
 
 
 class Entity(ClientObject):
+    """Base entity"""
+
+    def update(self):
+        """Updates the entity."""
+        qry = UpdateEntityQuery(self)
+        self.context.add_query(qry)
+        return self
+
+    def delete_object(self):
+        """Deletes the entity."""
+        qry = DeleteEntityQuery(self)
+        self.context.add_query(qry)
+        self.remove_from_parent_collection()
+        return self
 
     @property
     def context(self):
@@ -20,14 +36,10 @@ class Entity(ClientObject):
         """The unique identifier of the drive.
         :rtype: str or None
         """
-        if self.is_property_available("id"):
-            return self.properties['id']
-        return None
+        return self.properties.get('id', None)
 
     def set_property(self, name, value, persist_changes=True):
         super(Entity, self).set_property(name, value, persist_changes)
         if name == "id" and self._resource_path is None:
-            self._resource_path = ResourcePath(
-                value,
-                self._parent_collection.resource_path)
+            self._resource_path = ResourcePath(value, self._parent_collection.resource_path)
         return self
