@@ -7,6 +7,9 @@ from office365.directory.directoryObjectCollection import DirectoryObjectCollect
 from office365.directory.group_collection import GroupCollection
 from office365.directory.groupSettingTemplateCollection import GroupSettingTemplateCollection
 from office365.directory.identityProviderCollection import IdentityProviderCollection
+from office365.directory.organization import Organization
+from office365.directory.servicePrincipal import ServicePrincipalCollection
+from office365.directory.subscribedSku import SubscribedSkuCollection
 from office365.directory.user import User
 from office365.directory.userCollection import UserCollection
 from office365.onedrive.driveCollection import DriveCollection
@@ -120,7 +123,7 @@ class GraphClient(ClientRuntimeContext):
         return SharedDriveItemCollection(self, ResourcePath("shares"))
 
     @property
-    def directoryObjects(self):
+    def directory_objects(self):
         """Get Directory Objects"""
         return DirectoryObjectCollection(self, ResourcePath("directoryObjects"))
 
@@ -145,7 +148,7 @@ class GraphClient(ClientRuntimeContext):
         return Directory(self, ResourcePath("directory"))
 
     @property
-    def identityProviders(self):
+    def identity_providers(self):
         """Represents a deleted item in the directory"""
         return IdentityProviderCollection(self, ResourcePath("identityProviders"))
 
@@ -153,3 +156,17 @@ class GraphClient(ClientRuntimeContext):
     def applications(self):
         """Get the list of applications in this organization."""
         return ApplicationCollection(self, ResourcePath("applications"))
+
+    @property
+    def service_principals(self):
+        """Retrieve a list of servicePrincipal objects."""
+        return ServicePrincipalCollection(self, ResourcePath("servicePrincipals"))
+
+    @property
+    def organization(self):
+        return Organization(self, ResourcePath("organization"))
+
+    @property
+    def subscribed_skus(self):
+        """Retrieve a list of servicePrincipal objects."""
+        return SubscribedSkuCollection(self, ResourcePath("subscribedSkus"))
