@@ -11,6 +11,7 @@ from office365.onedrive.folder import Folder
 from office365.onedrive.listItem import ListItem
 from office365.onedrive.publicationFacet import PublicationFacet
 from office365.onedrive.uploadSession import UploadSession
+from office365.excel.workbook import Workbook
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.queries.create_entity_query import CreateEntityQuery
@@ -22,27 +23,27 @@ class DriveItem(BaseItem):
     """The driveItem resource represents a file, folder, or other item stored in a drive. All file system objects in
     OneDrive and SharePoint are returned as driveItem resources """
 
-    def create_link(self, type_, scope="", expirationDateTime=None, password=None, message=""):
+    def create_link(self, link_type, scope="", expiration_datetime=None, password=None, message=""):
         """
         The createLink action will create a new sharing link if the specified link type doesn't already exist
         for the calling application. If a sharing link of the specified type already exists for the app,
         the existing sharing link will be returned.
 
-        :param str type_: The type of sharing link to create. Either view, edit, or embed.
+        :param str link_type: The type of sharing link to create. Either view, edit, or embed.
         :param str scope:  The scope of link to create. Either anonymous or organization.
-        :param str expirationDateTime: A String with format of yyyy-MM-ddTHH:mm:ssZ of DateTime indicates the expiration
+        :param str expiration_datetime: A String with format of yyyy-MM-ddTHH:mm:ssZ of DateTime indicates the expiration
             time of the permission.
         :param str password: The password of the sharing link that is set by the creator. Optional
             and OneDrive Personal only.
         :param str message:
         """
         payload = {
-            "type": type_,
+            "type": link_type,
             "scope": scope,
-            "message": message
+            "message": message,
+            "expirationDateTime": expiration_datetime,
+            "password": password
         }
-        payload = {k: v for k, v in payload.items() if v is not None}
-
         permission = Permission(self.context)
         self.permissions.add_child(permission)
         qry = ServiceOperationQuery(self, "createLink", None, payload, None, permission)
@@ -119,7 +120,7 @@ class DriveItem(BaseItem):
 
         :type item: office365.graph.onedrive.driveItemUploadableProperties.DriveItemUploadableProperties
         """
-        result = ClientResult(UploadSession())
+        result = ClientResult(self.context, UploadSession())
         qry = ServiceOperationQuery(self,
                                     "createUploadSession",
                                     None,
@@ -156,12 +157,15 @@ class DriveItem(BaseItem):
         return qry.return_type
 
     def download(self, file_object):
+        """
+        :type file_object: typing.IO
+        """
         result = self.get_content()
 
         def _content_downloaded(resp):
             file_object.write(result.value)
-
         self.context.after_execute(_content_downloaded)
+        return self
 
     def create_folder(self, name):
         """Create a new folder or DriveItem in a Drive with a specified parent item or path.
@@ -198,7 +202,7 @@ class DriveItem(BaseItem):
         :type name: str
         :type parent_reference: ItemReference or None
         """
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self,
                                     "copy",
                                     None,
@@ -220,7 +224,7 @@ class DriveItem(BaseItem):
         :type parent_reference: ItemReference
         """
 
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self,
                                     "move",
                                     None,
@@ -244,7 +248,7 @@ class DriveItem(BaseItem):
         a whole drive, or files shared with the current user.
 
         :type query_text: str"""
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = SearchQuery(self, query_text, result)
         self.context.add_query(qry)
         return result
@@ -296,27 +300,25 @@ class DriveItem(BaseItem):
     def children(self):
         """Collection containing Item objects for the immediate children of Item. Only items representing folders
         have children."""
-        if self.is_property_available('children'):
-            return self.properties['children']
-        else:
-            from office365.onedrive.driveItemCollection import DriveItemCollection
-            return DriveItemCollection(self.context, ResourcePath("children", self.resource_path))
+        from office365.onedrive.driveItemCollection import DriveItemCollection
+        return self.properties.get('children',
+                                   DriveItemCollection(self.context, ResourcePath("children", self.resource_path)))
 
     @property
     def listItem(self):
         """For drives in SharePoint, the associated document library list item."""
-        if self.is_property_available('listItem'):
-            return self.properties['listItem']
-        else:
-            return ListItem(self.context, ResourcePath("listItem", self.resource_path))
+        return self.properties.get('listItem', ListItem(self.context, ResourcePath("listItem", self.resource_path)))
+
+    @property
+    def workbook(self):
+        """For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. """
+        return self.properties.get('workbook', Workbook(self.context, ResourcePath("workbook", self.resource_path)))
 
     @property
     def permissions(self):
         """The set of permissions for the item. Read-only. Nullable."""
-        if self.is_property_available('permissions'):
-            return self.properties['permissions']
-        else:
-            return PermissionCollection(self.context, ResourcePath("permissions", self.resource_path))
+        return self.properties.get('permissions',
+                                   PermissionCollection(self.context, ResourcePath("permissions", self.resource_path)))
 
     @property
     def publication(self):
@@ -336,9 +338,7 @@ class DriveItem(BaseItem):
         super(DriveItem, self).set_property(name, value, persist_changes)
         if name == "id" and self._resource_path.parent.segment == "children":
             self._resource_path = ResourcePath(
-                value,
-                ResourcePath("items", self._parent_collection.resource_path.parent.parent))
-        # elif name == "id" and self._resource_path.parent.segment == "root":
-        #    self._resource_path = ResourcePath(value,
-        #                                       ResourcePath("items", self._resource_path.parent.parent))
+                value, ResourcePath("items", self._parent_collection.resource_path.parent.parent))
+        elif name == "id" and self._resource_path.parent.segment == "root":
+            self._resource_path = ResourcePath(value, ResourcePath("items", self._resource_path.parent.parent))
         return self
