@@ -5,13 +5,18 @@ class ODataJsonFormat(object):
     """OData JSON format"""
 
     def __init__(self, metadata=None):
+        """
+
+        :type metadata: str
+        """
         self.metadata = metadata
         self.security_tag_name = None
+        self.function_tag_name = None
         self.collection_tag_name = None
         self.collection_next_tag_name = None
 
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def build_http_headers(self):
+    def get_media_type(self):
         pass
