@@ -39,8 +39,7 @@ class BatchQuery(ClientQuery):
         self._queries.append(query)
 
     def get(self, index):
-        result = [qry for qry in self.change_sets if qry.return_type is not None] + \
-                 [qry for qry in self._queries if isinstance(qry, ReadEntityQuery)]
+        result = [qry for qry in self.change_sets if qry.return_type is not None] + self.get_queries
         return result[index]
 
     @property
@@ -51,17 +50,14 @@ class BatchQuery(ClientQuery):
     def change_sets(self):
         return [qry for qry in self._queries if not isinstance(qry, ReadEntityQuery)]
 
+    @property
+    def queries(self):
+        return self._queries
+
+    @property
+    def get_queries(self):
+        return [qry for qry in self._queries if isinstance(qry, ReadEntityQuery)]
+
     @property
     def has_change_sets(self):
         return len(self.change_sets) > 0
-
-    def next_get_query(self):
-        for qry in self._queries:
-            if isinstance(qry, ReadEntityQuery):
-                self.context.pending_request()._current_query = qry
-                yield qry
-
-    def next_change_set(self):
-        for qry in self.change_sets:
-            self.context.pending_request()._current_query = qry
-            yield qry
