@@ -1,11 +1,11 @@
 from office365.runtime.client_result import ClientResult
-from office365.runtime.queries.serviceOperationQuery import ServiceOperationQuery
+from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 
 
 class GetWebUrlFromPageUrlQuery(ServiceOperationQuery):
 
     def __init__(self, context, page_full_url):
-        result = ClientResult(str)
+        result = ClientResult(context)
         payload = {
             "pageFullUrl": page_full_url
         }
