@@ -1,4 +1,4 @@
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
+from office365.runtime.client_result import ClientResult
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.base_entity import BaseEntity
@@ -60,10 +60,16 @@ class Field(BaseEntity):
         return field
 
     def enable_index(self):
-        pass
+        result = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "enableIndex", None, None, None, result)
+        self.context.add_query(qry)
+        return result
 
     def disable_index(self):
-        pass
+        result = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "disableIndex", None, None, None, result)
+        self.context.add_query(qry)
+        return result
 
     def set_show_in_display_form(self, flag):
         """Sets the value of the ShowInDisplayForm property for this fields.
@@ -87,13 +93,6 @@ class Field(BaseEntity):
         self.context.add_query(qry)
         return self
 
-    def delete_object(self):
-        """Deletes the fields."""
-        qry = DeleteEntityQuery(self)
-        self.context.add_query(qry)
-        self.remove_from_parent_collection()
-        return self
-
     @property
     def id(self):
         """Gets a value that specifies the field identifier.
@@ -102,6 +101,13 @@ class Field(BaseEntity):
         """
         return self.properties.get('Id', None)
 
+    @property
+    def default_formula(self):
+        """
+        :rtype: str or None
+        """
+        return self.properties.get('DefaultFormula', None)
+
     @property
     def schema_xml(self):
         """Gets a value that specifies the XML schema that defines the field.
@@ -165,6 +171,88 @@ class Field(BaseEntity):
         """
         return self.properties.get('InternalName', None)
 
+    @property
+    def can_be_deleted(self):
+        """Gets a value that specifies whether the field can be deleted
+
+        :rtype: bool or None
+        """
+        return self.properties.get('CanBeDeleted', None)
+
+    @property
+    def client_side_component_id(self):
+        """
+        :rtype: str or None
+        """
+        return self.properties.get('ClientSideComponentId', None)
+
+    @property
+    def client_side_component_properties(self):
+        """
+        :rtype: str or None
+        """
+        return self.properties.get('ClientSideComponentProperties', None)
+
+    @property
+    def js_link(self):
+        """
+        When implemented in a derived class, gets or sets the name of an external JavaScript file that contains
+        any client rendering logic for fields of the derived type.
+
+        :rtype: str or None
+        """
+        return self.properties.get('JSLink', None)
+
+    @property
+    def hidden(self):
+        """
+        Gets a value that specifies whether the field is hidden in list views and list forms.
+
+        :rtype: bool or None
+        """
+        return self.properties.get('Hidden', None)
+
+    @hidden.setter
+    def hidden(self, val):
+        """
+        Sets a value that specifies whether the field is hidden in list views and list forms.
+        """
+        self.set_property("Hidden", val)
+
+    @property
+    def default_value(self):
+        """
+        Gets  a value that specifies the default value for the field.
+
+        :rtype: str or None
+        """
+        return self.properties.get('DefaultValue', None)
+
+    @default_value.setter
+    def default_value(self, val):
+        """
+        Sets a value that specifies the default value for the field.
+        """
+        self.set_property("DefaultValue", val)
+
+    @property
+    def type_display_name(self):
+        """
+        Gets a value that specifies the display name for the type of the field.
+
+        :rtype: str or None
+        """
+        return self.properties.get('TypeDisplayName', None)
+
+    @property
+    def type_short_description(self):
+        """
+        Gets a value that specifies the description for the type of the field.
+
+        :rtype: str or None
+        """
+        return self.properties.get('TypeShortDescription', None)
+
     def set_property(self, name, value, persist_changes=True):
         super(Field, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
