@@ -1,12 +1,12 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.http.request_options import RequestOptions
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.actions.download_file import DownloadFileQuery
 from office365.sharepoint.base_entity import BaseEntity
+from office365.sharepoint.directory.user import User
 from office365.sharepoint.files.file_version_collection import FileVersionCollection
 from office365.sharepoint.listitems.listitem import ListItem
 from office365.sharepoint.webparts.limited_webpart_manager import LimitedWebPartManager
@@ -29,12 +29,6 @@ class AbstractFile(BaseEntity):
             self.context, self.properties["ServerRelativeUrl"], content)
         return response
 
-    def delete_object(self):
-        """Deletes the file."""
-        qry = DeleteEntityQuery(self)
-        self.context.add_query(qry)
-        return self
-
 
 class File(AbstractFile):
     """Represents a file in a SharePoint Web site that can be a Web Part Page, an item in a document library,
@@ -56,7 +50,7 @@ class File(AbstractFile):
     def recycle(self):
         """Moves the file to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
 
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "Recycle", None, None, None, result)
         self.context.add_query(qry)
         return result
@@ -72,6 +66,7 @@ class File(AbstractFile):
                                         "comment": comment
                                     })
         self.context.add_query(qry)
+        return self
 
     def deny(self, comment):
         """Denies approval for a file that was submitted for content approval.
@@ -84,6 +79,7 @@ class File(AbstractFile):
                                         "comment": comment
                                     })
         self.context.add_query(qry)
+        return self
 
     def copyto(self, new_relative_url, overwrite):
         """Copies the file to the destination URL.
@@ -156,6 +152,7 @@ class File(AbstractFile):
                                     }
                                     )
         self.context.add_query(qry)
+        return self
 
     def checkout(self):
         """Checks out the file from a document library based on the check-out type."""
@@ -163,6 +160,7 @@ class File(AbstractFile):
                                     "checkout",
                                     )
         self.context.add_query(qry)
+        return self
 
     def checkin(self, comment, checkin_type):
         """
@@ -182,6 +180,7 @@ class File(AbstractFile):
                                     }
                                     )
         self.context.add_query(qry)
+        return self
 
     def undocheckout(self):
         """Reverts an existing checkout for the file."""
@@ -189,6 +188,7 @@ class File(AbstractFile):
                                     "undocheckout"
                                     )
         self.context.add_query(qry)
+        return self
 
     def get_limited_webpart_manager(self, scope):
         """Specifies the control set used to access, modify, or add Web Parts associated with this Web Part Page and
@@ -206,7 +206,7 @@ class File(AbstractFile):
         :param bytes content: File content
         :param str upload_id: Upload session id
         """
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self,
                                     "startUpload",
                                     {
@@ -227,7 +227,7 @@ class File(AbstractFile):
         :param int file_offset: File offset
         :param bytes content: File content
         """
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self,
                                     "continueUpload",
                                     {
@@ -342,6 +342,24 @@ class File(AbstractFile):
         return self.properties.get('Versions',
                                    FileVersionCollection(self.context, ResourcePath("versions", self.resource_path)))
 
+    @property
+    def modified_by(self):
+        """
+        Gets a value that returns the user who last modified the file.
+
+        :rtype: office365.sharepoint.directory.user.User or None
+        """
+        return self.properties.get("ModifiedBy", User(self.context, ResourcePath("ModifiedBy", self.resource_path)))
+
+    @property
+    def locked_by_user(self):
+        """
+        Gets a value that returns the user that owns the current lock on the file.
+
+        :rtype: office365.sharepoint.directory.user.User or None
+        """
+        return self.properties.get("LockedByUser", User(self.context, ResourcePath("LockedByUser", self.resource_path)))
+
     @property
     def serverRelativeUrl(self):
         """Gets the relative URL of the file based on the URL for the server.
@@ -378,6 +396,14 @@ class File(AbstractFile):
         """
         return self.properties.get("Name", None)
 
+    @property
+    def list_id(self):
+        """Gets the GUID that identifies the List containing the file.
+
+        :rtype: str or None
+        """
+        return self.properties.get("ListId", None)
+
     @property
     def site_id(self):
         """Gets the GUID that identifies the site collection containing the file.
@@ -394,6 +420,14 @@ class File(AbstractFile):
         """
         return self.properties.get("WebId", None)
 
+    @property
+    def time_created(self):
+        """Gets a value that specifies when the file was created.
+
+        :rtype: str or None
+        """
+        return self.properties.get("TimeCreated", None)
+
     @property
     def time_last_modified(self):
         """Specifies when the file was last modified.
@@ -402,18 +436,41 @@ class File(AbstractFile):
         """
         return self.properties.get("TimeLastModified", None)
 
+    @property
+    def minor_version(self):
+        """
+        Gets a value that specifies the minor version of the file.
+
+        :rtype: int or None
+        """
+        return self.properties.get("MinorVersion", None)
+
+    @property
+    def major_version(self):
+        """
+        Gets a value that specifies the major version of the file.
+
+        :rtype: int or None
+        """
+        return self.properties.get("MajorVersion", None)
+
+    @property
+    def unique_id(self):
+        """
+        Gets a value that specifies the a file unique identifier
+
+        :rtype: str or None
+        """
+        return self.properties.get("UniqueId", None)
+
     def set_property(self, name, value, persist_changes=True):
         super(File, self).set_property(name, value, persist_changes)
         # fallback: create a new resource path
         if self._resource_path is None:
             if name == "ServerRelativeUrl":
                 self._resource_path = ResourcePathServiceOperation(
-                    "GetFileByServerRelativeUrl",
-                    [value],
-                    ResourcePath("Web"))
+                    "GetFileByServerRelativeUrl", [value], ResourcePath("Web"))
             elif name == "UniqueId":
                 self._resource_path = ResourcePathServiceOperation(
-                    "GetFileById",
-                    [value],
-                    ResourcePath("Web"))
+                    "GetFileById", [value], ResourcePath("Web"))
         return self
