@@ -1,12 +1,15 @@
-from office365.runtime.client_object_collection import ClientObjectCollection
+import os
+
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.actions.create_file import CreateFileQuery
 from office365.sharepoint.actions.upload_session import UploadSessionQuery
+from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.files.file import File
+from office365.sharepoint.files.file_creation_information import FileCreationInformation
 
 
-class FileCollection(ClientObjectCollection):
+class FileCollection(BaseEntityCollection):
     """Represents a collection of File resources."""
 
     def __init__(self, context, resource_path=None):
@@ -19,17 +22,27 @@ class FileCollection(ClientObjectCollection):
         """
         return super(FileCollection, self).get()
 
-    def create_upload_session(self, source_path, chunk_size, chunk_uploaded=None):
+    def create_upload_session(self, source_path, chunk_size, chunk_uploaded=None, *chunk_func_args):
         """Upload a file as multiple chunks
 
         :param str source_path: path where file to upload resides
         :param int chunk_size: upload chunk size
         :param (long)->None or None chunk_uploaded: uploaded event
+        :param chunk_func_args: arguments to pass to chunk_uploaded function
         :return: office365.sharepoint.files.file.File
         """
-        qry = UploadSessionQuery(self, source_path, chunk_size, chunk_uploaded)
-        self.context.add_query(qry)
-        return qry.file
+        file_size = os.path.getsize(source_path)
+        if file_size > chunk_size:
+            qry = UploadSessionQuery(self, source_path, chunk_size, chunk_uploaded, chunk_func_args)
+            self.context.add_query(qry)
+            return qry.file
+        else:
+            with open(source_path, 'rb') as content_file:
+                file_content = content_file.read()
+            info = FileCreationInformation(url=os.path.basename(source_path), overwrite=True, content=file_content)
+            qry = CreateFileQuery(self, info)
+            self.context.add_query(qry)
+            return qry.return_type
 
     def add(self, file_creation_information):
         """Creates a File resource
