@@ -1,13 +1,13 @@
 import os
 
-from office365.runtime.client_object_collection import ClientObjectCollection
 from office365.runtime.queries.create_entity_query import CreateEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
+from office365.sharepoint.base_entity_collection import BaseEntityCollection
 from office365.sharepoint.folders.folder import Folder
 
 
-class FolderCollection(ClientObjectCollection):
+class FolderCollection(BaseEntityCollection):
     """Represents a collection of Folder resources."""
     def __init__(self, context, resource_path=None):
         super(FolderCollection, self).__init__(context, Folder, resource_path)
@@ -33,6 +33,10 @@ class FolderCollection(ClientObjectCollection):
         return target_folder
 
     def get_by_path(self, decoded_url):
+        """
+
+        :type decoded_url: str
+        """
         from office365.sharepoint.types.resource_path import ResourcePath as SPResPath
         target_folder = Folder(self.context)
         qry = ServiceOperationQuery(self, "GetByPath", SPResPath(decoded_url), None, "parameters", target_folder)
@@ -41,9 +45,9 @@ class FolderCollection(ClientObjectCollection):
 
     def ensure_folder_path(self, path):
         """
-        Function to create a folder
-        :type path: string
-        :param path: relative server URL (path) to a folder
+        Ensures a nested folder hierarchy exist
+
+        :param str path: relative server URL (path) to a folder
         """
 
         url_component = os.path.normpath(path).split(os.path.sep)
