@@ -1,8 +1,6 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
-from office365.runtime.queries.update_entity_query import UpdateEntityQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.changes.change_collection import ChangeCollection
@@ -10,6 +8,7 @@ from office365.sharepoint.changes.change_query import ChangeQuery
 from office365.sharepoint.comments.comment_collection import CommentCollection
 from office365.sharepoint.fields.field_lookup_value import FieldLookupValue
 from office365.sharepoint.fields.fieldMultiLookupValue import FieldMultiLookupValue
+from office365.sharepoint.likes.likedByInformation import LikedByInformation
 from office365.sharepoint.permissions.securable_object import SecurableObject
 from office365.sharepoint.sharing.externalSharingSiteOption import ExternalSharingSiteOption
 from office365.sharepoint.sharing.object_sharing_information import ObjectSharingInformation
@@ -29,7 +28,7 @@ class ListItem(SecurableObject):
             application associated with the list item.
         :param int action:
         """
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "GetWOPIFrameUrl", [action], None, None, result)
         self.context.add_query(qry)
         return result
@@ -37,7 +36,7 @@ class ListItem(SecurableObject):
     def recycle(self):
         """Moves the listItem to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
 
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "Recycle", None, None, None, result)
         self.context.add_query(qry)
         return result
@@ -66,11 +65,11 @@ class ListItem(SecurableObject):
         :param bool sendEmail: A flag to determine if an email notification SHOULD be sent (if email is configured).
         :param str emailSubject: The email subject.
         :param str emailBody: The email subject.
-        :return: SharingResult
+        :rtype: SharingResult
         """
 
-        result = ClientResult(SharingResult(self.context))
-        file_result = ClientResult(str)
+        result = ClientResult(self.context, SharingResult(self.context))
+        file_result = ClientResult(self.context)
 
         role_values = {
             ExternalSharingSiteOption.View: "role:1073741826",
@@ -94,9 +93,11 @@ class ListItem(SecurableObject):
 
     def unshare(self):
         """
-                Share a ListItem (file or folder facet)
+        Unshare a ListItem (file or folder facet)
+
+        :rtype: SharingResult
         """
-        result = ClientResult(SharingResult(self.context))
+        result = ClientResult(self.context, SharingResult(self.context))
 
         def _property_resolved():
             abs_url = self.get_property("EncodedAbsUrl")
@@ -109,9 +110,9 @@ class ListItem(SecurableObject):
     def get_sharing_information(self):
         """
 
-        :rtype: ClientResult
+        :rtype: ObjectSharingInformation
         """
-        result = ClientResult(ObjectSharingInformation(self.context))
+        result = ClientResult(self.context, ObjectSharingInformation(self.context))
 
         def _item_resolved():
             result.value = ObjectSharingInformation.get_list_item_sharing_information(
@@ -120,13 +121,6 @@ class ListItem(SecurableObject):
         self.ensure_properties(["Id", "ParentList"], _item_resolved)
         return result.value
 
-    def update(self):
-        """Update the list item."""
-        self.ensure_type_name(self.parent_list)
-        qry = UpdateEntityQuery(self)
-        self.context.add_query(qry)
-        return self
-
     def validate_update_list_item(self, form_values, new_document_update):
         """Validates and sets the values of the specified collection of fields for the list item."""
         qry = ServiceOperationQuery(self,
@@ -153,12 +147,6 @@ class ListItem(SecurableObject):
         self.context.add_query(qry)
         return self
 
-    def delete_object(self):
-        """Deletes the ListItem."""
-        qry = DeleteEntityQuery(self)
-        self.context.add_query(qry)
-        return self
-
     def set_comments_disabled(self, value):
         """
         :type value: bool
@@ -217,12 +205,10 @@ class ListItem(SecurableObject):
     @property
     def attachment_files(self):
         """Specifies the collection of attachments that are associated with the list item.<62>"""
-        if self.is_property_available('AttachmentFiles'):
-            return self.properties["AttachmentFiles"]
-        else:
-            from office365.sharepoint.attachments.attachmentfile_collection import AttachmentFileCollection
-            return AttachmentFileCollection(self.context,
-                                            ResourcePath("AttachmentFiles", self.resource_path))
+        from office365.sharepoint.attachments.attachmentfile_collection import AttachmentFileCollection
+        return self.properties.get("AttachmentFiles",
+                                   AttachmentFileCollection(self.context,
+                                                            ResourcePath("AttachmentFiles", self.resource_path)))
 
     @property
     def content_type(self):
@@ -267,6 +253,16 @@ class ListItem(SecurableObject):
         """
         return self.properties.get("Id", None)
 
+    @property
+    def liked_by_information(self):
+        """
+        Gets a value that specifies the list item identifier.
+        :rtype: int
+        """
+        return self.properties.get("LikedByInformation",
+                                   LikedByInformation(self.context,
+                                                      ResourcePath("likedByInformation", self.resource_path)))
+
     def get_property(self, name):
         if name == "ContentType":
             return self.content_type
@@ -276,6 +272,8 @@ class ListItem(SecurableObject):
             return self.effective_base_permissions
         elif name == "AttachmentFiles":
             return self.attachment_files
+        elif name == "LikedByInformation":
+            return self.liked_by_information
         else:
             return super(ListItem, self).get_property(name)
 
