@@ -1,12 +1,13 @@
 from office365.runtime.client_result import ClientResult
 from office365.runtime.client_value_collection import ClientValueCollection
-from office365.runtime.queries.delete_entity_query import DeleteEntityQuery
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.changes.change_collection import ChangeCollection
 from office365.sharepoint.changes.change_query import ChangeQuery
 from office365.sharepoint.contenttypes.content_type_collection import ContentTypeCollection
+from office365.sharepoint.customactions.custom_action_element import CustomActionElement
+from office365.sharepoint.eventreceivers.event_receiver_definition import EventReceiverDefinitionCollection
 from office365.sharepoint.fields.field_collection import FieldCollection
 from office365.sharepoint.fields.related_field_collection import RelatedFieldCollection
 from office365.sharepoint.files.checkedOutFileCollection import CheckedOutFileCollection
@@ -28,11 +29,31 @@ from office365.sharepoint.utilities.utility import Utility
 
 
 class List(SecurableObject):
-    """List resource"""
+    """Represents a list on a SharePoint Web site."""
 
     def __init__(self, context, resource_path=None):
         super(List, self).__init__(context, resource_path)
 
+    def recycle(self):
+        """Moves the list to the Recycle Bin and returns the identifier of the new Recycle Bin item."""
+        result = ClientResult(self.context)
+        qry = ServiceOperationQuery(self, "Recycle", None, None, None, result)
+        self.context.add_query(qry)
+        return result
+
+    def render_list_data(self, viewXml):
+        """
+
+        :param str viewXml: View xml
+        """
+        result = ClientResult(self.context)
+        payload = {
+            "viewXml": viewXml
+        }
+        qry = ServiceOperationQuery(self, "RenderListData", None, payload, None, result)
+        self.context.add_query(qry)
+        return result
+
     @staticmethod
     def get_list_data_as_stream(context, list_full_url, parameters=None):
         """
@@ -41,7 +62,7 @@ class List(SecurableObject):
         :param str list_full_url:
         :param RenderListDataParameters parameters:
         """
-        result = ClientResult(None)
+        result = ClientResult(context)
         payload = {
             "listFullUrl": list_full_url,
             "parameters": parameters,
@@ -74,7 +95,7 @@ class List(SecurableObject):
         return result
 
     def get_lookup_field_choices(self, targetFieldName, pagingInfo=None):
-        result = ClientResult(str)
+        result = ClientResult(self.context)
         params = {
             "targetFieldName": targetFieldName,
             "pagingInfo": pagingInfo
@@ -88,7 +109,7 @@ class List(SecurableObject):
 
         :type query: office365.sharepoint.changes.change_log_item_query.ChangeLogItemQuery
         """
-        result = ClientResult(str)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "getListItemChangesSinceToken", None, query, "query", result)
         self.context.add_query(qry)
         return result
@@ -130,7 +151,7 @@ class List(SecurableObject):
         :return: ClientResult
         """
 
-        result = ClientResult(str)
+        result = ClientResult(self.context)
         payload = {
             "sourceUrl": source_url
         }
@@ -183,7 +204,7 @@ class List(SecurableObject):
         :param str page_name:
         :param str page_content:
         """
-        result = ClientResult(File)
+        result = ClientResult(self.context, File(self.context))
 
         def _list_loaded():
             page_url = self.root_folder.serverRelativeUrl + "/" + page_name
@@ -251,16 +272,6 @@ class List(SecurableObject):
         return RelatedFieldCollection(self.context,
                                       ResourcePathServiceOperation("getRelatedFields", [], self.resource_path))
 
-    def delete_object(self):
-        """Deletes the list.
-
-        :rtype: List
-        """
-        qry = DeleteEntityQuery(self)
-        self.context.add_query(qry)
-        self.remove_from_parent_collection()
-        return self
-
     @property
     def enable_folder_creation(self):
         """
@@ -270,6 +281,15 @@ class List(SecurableObject):
         """
         return self.properties.get("EnableFolderCreation", None)
 
+    @property
+    def default_edit_form_url(self):
+        """
+        Gets a value that specifies the URL of the edit form to use for list items in the list.
+
+        :rtype: str or None
+        """
+        return self.properties.get("DefaultEditFormUrl", None)
+
     @enable_folder_creation.setter
     def enable_folder_creation(self, value):
         self.set_property("EnableFolderCreation", value, True)
@@ -277,26 +297,20 @@ class List(SecurableObject):
     @property
     def items(self):
         """Get list items"""
-        if self.is_property_available('Items'):
-            return self.properties["Items"]
-        else:
-            return ListItemCollection(self.context, ResourcePath("items", self.resource_path))
+        return self.properties.get("Items",
+                                   ListItemCollection(self.context, ResourcePath("items", self.resource_path)))
 
     @property
     def root_folder(self):
         """Get a root folder"""
-        if self.is_property_available('RootFolder'):
-            return self.properties["RootFolder"]
-        else:
-            return Folder(self.context, ResourcePath("RootFolder", self.resource_path))
+        return self.properties.get("RootFolder",
+                                   Folder(self.context, ResourcePath("RootFolder", self.resource_path)))
 
     @property
     def fields(self):
         """Gets a value that specifies the collection of all fields in the list."""
-        if self.is_property_available('Fields'):
-            return self.properties['Fields']
-        else:
-            return FieldCollection(self.context, ResourcePath("Fields", self.resource_path), self)
+        return self.properties.get('Fields',
+                                   FieldCollection(self.context, ResourcePath("Fields", self.resource_path), self))
 
     @property
     def subscriptions(self):
@@ -309,10 +323,8 @@ class List(SecurableObject):
     def views(self):
         """Gets a value that specifies the collection of all public views on the list and personal views
         of the current user on the list."""
-        if self.is_property_available('Views'):
-            return self.properties['Views']
-        else:
-            return ViewCollection(self.context, ResourcePath("views", self.resource_path), self)
+        return self.properties.get('Views',
+                                   ViewCollection(self.context, ResourcePath("views", self.resource_path), self))
 
     @property
     def default_view(self):
@@ -334,6 +346,11 @@ class List(SecurableObject):
                                    UserCustomActionCollection(self.context,
                                                               ResourcePath("UserCustomActions", self.resource_path)))
 
+    @property
+    def custom_action_elements(self):
+        return self.properties.get('CustomActionElements',
+                                   ClientValueCollection(CustomActionElement))
+
     @property
     def forms(self):
         """Gets a value that specifies the collection of all list forms in the list."""
@@ -347,6 +364,14 @@ class List(SecurableObject):
         return self.properties.get('ParentWeb',
                                    Web(self.context, ResourcePath("parentWeb", self.resource_path)))
 
+    @property
+    def event_receivers(self):
+        """Get Event receivers"""
+        return self.properties.get('EventReceivers',
+                                   EventReceiverDefinitionCollection(self.context,
+                                                                     ResourcePath("eventReceivers", self.resource_path),
+                                                                     self))
+
     @property
     def item_count(self):
         """Gets a value that specifies the number of list items in the list.
