@@ -1,8 +1,10 @@
 from office365.runtime.client_result import ClientResult
+from office365.runtime.client_value_collection import ClientValueCollection
 from office365.runtime.http.http_method import HttpMethod
 from office365.runtime.queries.service_operation_query import ServiceOperationQuery
 from office365.runtime.resource_path import ResourcePath
 from office365.sharepoint.base_entity import BaseEntity
+from office365.sharepoint.search.query.popularTenantQuery import PopularTenantQuery
 from office365.sharepoint.search.query.querySuggestionResults import QuerySuggestionResults
 from office365.sharepoint.search.searchResult import SearchResult
 
@@ -19,7 +21,7 @@ class SearchService(BaseEntity):
 
         :param datetime.datetime start_time: The timestamp of the oldest query log entry returned.
         :param str user_name: The name of the user that issued the queries."""
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         payload = {
             "userName": user_name,
             "startTime": start_time.isoformat()
@@ -32,12 +34,21 @@ class SearchService(BaseEntity):
         """"""
         pass
 
+    def export_popular_tenant_queries(self, count):
+        result = ClientResult(self.context, ClientValueCollection(PopularTenantQuery))
+        payload = {
+            "count": count,
+        }
+        qry = ServiceOperationQuery(self, "exportpopulartenantqueries", None, payload, None, result)
+        self.context.add_query(qry)
+        return result
+
     def query(self, search_request):
         """The operation is used to retrieve search results by using the HTTP protocol with the GET method.
 
-        :type search_request: SearchRequest
+        :type search_request: office365.sharepoint.search.searchRequest.SearchRequest
         """
-        result = SearchResult()
+        result = ClientResult(self.context, SearchResult())
         qry = ServiceOperationQuery(self, "query", search_request.to_json(), None, "query", result)
         self.context.add_query(qry)
 
@@ -47,7 +58,7 @@ class SearchService(BaseEntity):
             """
             request.method = HttpMethod.Get
 
-        self.context.before_execute(_construct_request, qry)
+        self.context.before_execute(_construct_request)
         return result
 
     def post_query(self, request):
@@ -55,7 +66,7 @@ class SearchService(BaseEntity):
         with method type POST.
 
         :type request: SearchRequest"""
-        result = SearchResult()
+        result = ClientResult(self.context, SearchResult())
         qry = ServiceOperationQuery(self, "postquery", None, request, "request", result)
         self.context.add_query(qry)
         return result
@@ -67,7 +78,7 @@ class SearchService(BaseEntity):
     def search_center_url(self):
         """The operation is used to get the URI address of the search center by using the HTTP protocol
         with the GET method. The operation returns the URI of the of the search center."""
-        result = ClientResult(None)
+        result = ClientResult(self.context)
         qry = ServiceOperationQuery(self, "searchCenterUrl", None, None, None, result)
         self.context.add_query(qry)
         return result
@@ -78,10 +89,13 @@ class SearchService(BaseEntity):
         pass
 
     def suggest(self, query_text):
-        result = QuerySuggestionResults()
+        result = ClientResult(self.context, QuerySuggestionResults())
         payload = {
             "querytext": query_text
         }
         qry = ServiceOperationQuery(self, "suggest", None, payload, None, result)
         self.context.add_query(qry)
         return result
+
+    def auto_completions(self):
+        pass
