@@ -4,6 +4,7 @@ from office365.runtime.resource_path import ResourcePath
 from office365.runtime.resource_path_service_operation import ResourcePathServiceOperation
 from office365.sharepoint.base_entity import BaseEntity
 from office365.sharepoint.changes.change_collection import ChangeCollection
+from office365.sharepoint.eventreceivers.event_receiver_definition import EventReceiverDefinitionCollection
 from office365.sharepoint.features.feature_collection import FeatureCollection
 from office365.sharepoint.lists.list import List
 from office365.sharepoint.principal.user import User
@@ -19,8 +20,14 @@ class Site(BaseEntity):
     def __init__(self, context):
         super(Site, self).__init__(context, ResourcePath("Site", None))
 
+    @staticmethod
+    def from_url(url):
+        from office365.sharepoint.client_context import ClientContext
+        client = ClientContext(url)
+        return client.site
+
     def is_valid_home_site(self):
-        result = ClientResult(None)
+        result = ClientResult(self.context)
 
         def _site_loaded():
             SPHSite.is_valid_home_site(self.context, self.url, result)
@@ -29,7 +36,7 @@ class Site(BaseEntity):
         return result
 
     def set_as_home_site(self):
-        result = ClientResult(None)
+        result = ClientResult(self.context)
 
         def _site_loaded():
             self.result = SPHSite.set_as_home_site(self.context, self.url, result)
@@ -49,6 +56,11 @@ class Site(BaseEntity):
         return changes
 
     def get_recycle_bin_items(self, rowLimit=100, isAscending=True):
+        """
+
+        :param int rowLimit:
+        :param bool isAscending:
+        """
         result = RecycleBinItemCollection(self.context)
         payload = {
             "rowLimit": rowLimit,
@@ -96,11 +108,12 @@ class Site(BaseEntity):
     @staticmethod
     def get_url_by_id(context, site_id, stop_redirect=False):
         """Gets Site Url By Id
+
         :type context: office365.sharepoint.client_context.ClientContext
         :type site_id: str
         :type stop_redirect: bool
         """
-        result = ClientResult(str)
+        result = ClientResult(context)
         payload = {
             "id": site_id,
             "stopRedirect": stop_redirect
@@ -120,7 +133,7 @@ class Site(BaseEntity):
         :type context: office365.sharepoint.client_context.ClientContext
         :type url: str
         """
-        result = ClientResult(bool)
+        result = ClientResult(context)
         payload = {
             "url": url
         }
@@ -135,21 +148,29 @@ class Site(BaseEntity):
         :type type_catalog: int"""
         return List(self.context, ResourcePathServiceOperation("getCatalog", [type_catalog], self.resource_path))
 
+    def register_hub_site(self, creationInformation):
+        """Registers an existing site as a hub site.
+
+        :type creationInformation: HubSiteCreationInformation
+        """
+        qry = ServiceOperationQuery(self, "RegisterHubSite", None, creationInformation, "creationInformation", None)
+        self.context.add_query(qry)
+        return self
+
+    def unregister_hub_site(self):
+        qry = ServiceOperationQuery(self, "UnRegisterHubSite", None, None, None, None)
+        self.context.add_query(qry)
+        return self
+
     @property
     def root_web(self):
         """Get root web"""
-        if self.is_property_available('RootWeb'):
-            return self.properties['RootWeb']
-        else:
-            return Web(self.context, ResourcePath("RootWeb", self.resource_path))
+        return self.properties.get('RootWeb', Web(self.context, ResourcePath("RootWeb", self.resource_path)))
 
     @property
     def owner(self):
         """Gets or sets the owner of the site collection. (Read-only in sandboxed solutions.)"""
-        if self.is_property_available('owner'):
-            return self.properties['owner']
-        else:
-            return User(self.context, ResourcePath("owner", self.resource_path))
+        return self.properties.get('owner', User(self.context, ResourcePath("owner", self.resource_path)))
 
     @property
     def url(self):
@@ -162,6 +183,13 @@ class Site(BaseEntity):
         """
         return self.properties.get("Id", None)
 
+    @property
+    def is_hub_site(self):
+        """
+        :rtype: bool
+        """
+        return self.properties.get("IsHubSite", None)
+
     @property
     def recycle_bin(self):
         """Get recycle bin"""
@@ -176,10 +204,20 @@ class Site(BaseEntity):
                                    FeatureCollection(self.context,
                                                      ResourcePath("Features", self.resource_path), self))
 
+    @property
+    def event_receivers(self):
+        """Get Event receivers"""
+        return self.properties.get('EventReceivers',
+                                   EventReceiverDefinitionCollection(self.context,
+                                                                     ResourcePath("eventReceivers", self.resource_path),
+                                                                     self))
+
     def get_property(self, name):
         if name == "RecycleBin":
             return self.recycle_bin
         elif name == "RootWeb":
             return self.root_web
+        elif name == "EventReceivers":
+            return self.event_receivers
         else:
             return super(Site, self).get_property(name)
