@@ -1,8 +1,8 @@
+from office365.runtime.client_object import ClientObject
 from office365.runtime.resource_path import ResourcePath
-from office365.sharepoint.base_entity import BaseEntity
 
 
-class SiteCollectionManagementService(BaseEntity):
+class SiteCollectionManagementService(ClientObject):
 
     def __init__(self, context):
         fqn = "Microsoft.Online.SharePoint.TenantAdministration.SiteCollectionManagementService"
